.. Buckaroo documentation master file, created by
   sphinx-quickstart on Wed Apr 19 14:07:15 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Articles
========
Articles about Buckaroo can be found here.  It was more expedient to use Read The Docs for a common blog task than dealing with medium paywalls or yet another devops struggle.


.. toctree::
    :glob:

    .//*




* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
* `Buckaroo on github <https://github.com/paddymul/buckaroo>`_
